==> mouse4302.db_2.0.2.tar.gz: mouse4302.db/man/mouse4302_dbconn.Rd <==
\name{mouse4302_dbconn}

\alias{mouse4302_dbconn}
\alias{mouse4302_dbfile}
\alias{mouse4302_dbschema}
\alias{mouse4302_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mouse4302_dbconn()
  mouse4302_dbfile()
  mouse4302_dbschema(file="", show.indices=FALSE)
  mouse4302_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mouse4302_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{mouse4302_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{mouse4302_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mouse4302_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mouse4302_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mouse4302_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{mouse4302_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mouse4302_dbschema}: none (invisible \code{NULL}).

  \code{mouse4302_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mouse4302_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mouse4302_dbconn() was created with:
  dbConnect(SQLite(), dbname=mouse4302_dbfile(), cache_size=64000, synchronous=0)

  mouse4302_dbschema()

  mouse4302_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> mouse4302.db_2.5.0.tar.gz: mouse4302.db/man/mouse4302_dbconn.Rd <==

\name{mouse4302_dbconn}

\alias{mouse4302_dbconn}
\alias{mouse4302_dbfile}
\alias{mouse4302_dbschema}
\alias{mouse4302_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mouse4302_dbconn()
  mouse4302_dbfile()
  mouse4302_dbschema(file="", show.indices=FALSE)
  mouse4302_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mouse4302_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{mouse4302_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{mouse4302_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mouse4302_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mouse4302_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mouse4302_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{mouse4302_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mouse4302_dbschema}: none (invisible \code{NULL}).

  \code{mouse4302_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mouse4302_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mouse4302_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=mouse4302_dbfile(), cache_size=64000,
  synchronous=0)

  mouse4302_dbschema()

  mouse4302_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
